package edu.nyu.scps.gallery;

import android.app.Activity;
import android.content.Context;
import android.content.res.TypedArray;
import android.os.Bundle;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.BaseAdapter;
import android.widget.Gallery;
import android.widget.ImageView;
import android.widget.Toast;

public class GalleryActivity extends Activity {
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		Gallery gallery = (Gallery)findViewById(R.id.gallery);
		gallery.setAdapter(new ImageAdapter(this));

		gallery.setOnItemClickListener(new OnItemClickListener() {
			public void onItemClick(AdapterView<?> parent, View v, int position, long id) {
				String s = String.format("%d: %d x %d", position, v.getWidth(), v.getHeight());
				Toast.makeText(GalleryActivity.this, s, Toast.LENGTH_SHORT).show();
			}
		});
	}

	public class ImageAdapter extends BaseAdapter {
		int galleryItemBackground;
		private Context context;

		private Integer[] imageIds = {
				R.drawable.ab4241,
				R.drawable.fg599,
				//R.drawable.wh521,
				R.drawable.ri2027,
				//R.drawable.pnk202,
				R.drawable.lk1332,
				R.drawable.shl249,
				R.drawable.hcl211,
				R.drawable.dm1969,
				//R.drawable.ym818,
				R.drawable.nrp243,
				R.drawable.jr3136,
				R.drawable.gv490
		};

		public ImageAdapter(Context c) {
			context = c;
			TypedArray a = obtainStyledAttributes(R.styleable.Gallery);
			galleryItemBackground = a.getResourceId(
					R.styleable.Gallery_android_galleryItemBackground, 0);
			a.recycle();
		}

		public int getCount() {
			return imageIds.length;
		}

		public Object getItem(int position) {
			return position;
		}

		public long getItemId(int position) {
			return position;
		}

		public View getView(int position, View convertView, ViewGroup parent) {
			ImageView imageView;

			if (convertView == null) {
				imageView = new ImageView(context);
				imageView.setImageResource(imageIds[position]);
				imageView.setLayoutParams(new Gallery.LayoutParams(300, 300));
				imageView.setScaleType(ImageView.ScaleType.FIT_XY);
				imageView.setBackgroundResource(galleryItemBackground);
			} else {
				imageView = (ImageView)convertView;	//recycled
			}

			return imageView;
		}
	}
}